"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const spl_token_1 = require("@solana/spl-token");
const web3_js_1 = require("@solana/web3.js");
const fs_1 = __importDefault(require("fs"));
async function main() {
    try {
        let sig;
        const conn = new web3_js_1.Connection(process.env.MB_CLUSTER_URL);
        // load wallet 1
        const w1 = web3_js_1.Keypair.fromSecretKey(Buffer.from(JSON.parse(fs_1.default.readFileSync(process.env.wallet1, 'utf-8'))));
        // load wallet 2
        const w2 = web3_js_1.Keypair.fromSecretKey(Buffer.from(JSON.parse(fs_1.default.readFileSync(process.env.wallet2, 'utf-8'))));
        const w1WsolTA = await (0, spl_token_1.getAssociatedTokenAddress)(spl_token_1.NATIVE_MINT, w1.publicKey);
        //   const ataTransaction1 = new Transaction().add(
        //     createAssociatedTokenAccountInstruction(
        //       w1.publicKey,
        //       w1WsolTA,
        //       w1.publicKey,
        //       NATIVE_MINT,
        //     ),
        //   );
        //   await sendAndConfirmTransaction(conn, ataTransaction1, [w1]);
        const w2WsolTA = await (0, spl_token_1.getAssociatedTokenAddress)(spl_token_1.NATIVE_MINT, w2.publicKey);
        //   const ataTransaction2 = new Transaction().add(
        //     createAssociatedTokenAccountInstruction(
        //       w2.publicKey,
        //       w2WsolTA,
        //       w2.publicKey,
        //       NATIVE_MINT,
        //     ),
        //   );
        //   await sendAndConfirmTransaction(conn, ataTransaction2, [w2]);
        // wallet 1 wrap sol to wsol
        const solTransferTransaction = new web3_js_1.Transaction().add(web3_js_1.SystemProgram.transfer({
            fromPubkey: w1.publicKey,
            toPubkey: w1WsolTA,
            lamports: 1,
        }), (0, spl_token_1.createSyncNativeInstruction)(w1WsolTA));
        sig = await (0, web3_js_1.sendAndConfirmTransaction)(conn, solTransferTransaction, [w1]);
        console.log(`sig w1 wrapped some sol https://explorer.solana.com/tx/${sig}`);
        // wallet 1 approve wallet 2 for some wsol
        const tokenApproveTx = new web3_js_1.Transaction().add((0, spl_token_1.createApproveInstruction)(w1WsolTA, w2.publicKey, w1.publicKey, 1));
        sig = await (0, web3_js_1.sendAndConfirmTransaction)(conn, tokenApproveTx, [w1]);
        console.log(`sig w1 token approve w2 https://explorer.solana.com/tx/${sig}`);
        // log delegate amount
        let w2WsolAtaInfo = await (0, spl_token_1.getAccount)(conn, w1WsolTA);
        console.log(`- delegate ${w2WsolAtaInfo.delegate}, amount ${w2WsolAtaInfo.delegatedAmount}`);
        // wallet 2 transfer wsol from wallet 1 to wallet 2
        const tokenTransferTx = new web3_js_1.Transaction().add((0, spl_token_1.createTransferInstruction)(w1WsolTA, w2WsolTA, w2.publicKey, 1));
        sig = await (0, web3_js_1.sendAndConfirmTransaction)(conn, tokenTransferTx, [w2], {
            skipPreflight: true,
        });
        console.log(`sig w1 transfer wsol to w2 https://explorer.solana.com/tx/${sig}`);
        // log delegate amount
        w2WsolAtaInfo = await (0, spl_token_1.getAccount)(conn, w1WsolTA, 'finalized');
        console.log(`- delegate ${w2WsolAtaInfo.delegate}, amount ${w2WsolAtaInfo.delegatedAmount}`);
        // wallet 2 unwrap all wsol
        const closeAtaIx = new web3_js_1.Transaction().add((0, spl_token_1.createCloseAccountInstruction)(w2WsolTA, w2.publicKey, w2.publicKey));
        sig = await (0, web3_js_1.sendAndConfirmTransaction)(conn, closeAtaIx, [w2], {
            skipPreflight: true,
        });
        console.log(`sig w2 unwrap wsol https://explorer.solana.com/tx/${sig}`);
    }
    catch (error) {
        console.log(error);
    }
}
main();
